#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/dconf/0.10/dconf-0.10.0.tar.xz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="dconf"
softversion="0.10.0"
arch="i486"
cpu="i686"
packageversion="72.2"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --disable-schemas-compile \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j6
make install DESTDIR=$dest

# Put icon in place
ICONSIZES="14 32 48 64 92 128"
for i in $ICONSIZES; do
	mkdir -p $dest/usr/share/icons/hicolor/$i\x$i/apps
	cp $buildir/icons/hicolor/$i\x$i/apps/dconf-editor.png $dest/usr/share/icons/hicolor/$i\x$i/apps/
done;

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

cp -a COPYING NEWS $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler----------------------------------------------------------|
dconf: dconf - is a low-level configuration system
dconf:
dconf: dconf is a low-level configuration system. Its main purpose is to provide
dconf: a backend to GSettings on platforms that don't already have configuration
dconf: storage systems.
dconf:
dconf:
dconf:
dconf:
dconf:
dconf:
EODESC

cat << DOINST > $dest/install/doinst.sh
# update desktop database
if [ -x usr/bin/gio-querymodules ]; then
  usr/lib/gio/modules 1> /dev/null 2> /dev/null
fi

# update glib schemas
if [ -x usr/bin/glib-compile-schemas ]; then
  usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas 1> /dev/null 2> /dev/null
fi
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
